ModalRouter class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- currentModal → ModalComponent?
-
no setter
- hasModals → bool
-
no setter
- instance → ModalRouter
-
no setter
Static Methods
-
init(
FlameGame< World> game) → dynamic -
pop(
) → void -
popAll(
) → void -
push(
ModalComponent modal) → void -
replace(
ModalComponent modal) → void